@@ -9,7 +9,7 @@ class UniversityHRClientConfiguration(ClientCredentialsConfigurationMixin, Confi
         client_key,
         client_secret,
         access_token_url="https://api.apps.cam.ac.uk/oauth2/v1/token",
-        base_url="https://api.apps.cam.ac.uk/university-human-resources"
+        base_url="https://api.apps.cam.ac.uk/university-human-resources/v1alpha2"
     ):
 
         ClientCredentialsConfigurationMixin.__init__(
